about summary refs log tree commit diff
path: root/pkgs/development/haskell-modules
diff options
context:
space:
mode:
authorsternenseemann <sternenseemann@systemli.org>2023-01-25 16:30:46 +0100
committersternenseemann <sternenseemann@systemli.org>2023-01-25 16:30:46 +0100
commitf8d0403e2eee98ca3ecd2e98261ad57f9d83f5c8 (patch)
treea9eb8e9e0906603c304d4106701dec6048384e32 /pkgs/development/haskell-modules
parent48eface5caea77e1e15925723e1cdff8f10c9a37 (diff)
downloadnixlib-f8d0403e2eee98ca3ecd2e98261ad57f9d83f5c8.tar
nixlib-f8d0403e2eee98ca3ecd2e98261ad57f9d83f5c8.tar.gz
nixlib-f8d0403e2eee98ca3ecd2e98261ad57f9d83f5c8.tar.bz2
nixlib-f8d0403e2eee98ca3ecd2e98261ad57f9d83f5c8.tar.lz
nixlib-f8d0403e2eee98ca3ecd2e98261ad57f9d83f5c8.tar.xz
nixlib-f8d0403e2eee98ca3ecd2e98261ad57f9d83f5c8.tar.zst
nixlib-f8d0403e2eee98ca3ecd2e98261ad57f9d83f5c8.zip
haskellPackages.brick-skylighting: drop stale version constraint
We _need_ brick-skylighting-1.0 now to be compatible with the latest
brick version. matterhorn still needs the old 0.3 version, as it is also
still using an old brick version.
Diffstat (limited to 'pkgs/development/haskell-modules')
-rw-r--r--pkgs/development/haskell-modules/configuration-common.nix3
-rw-r--r--pkgs/development/haskell-modules/configuration-hackage2nix/main.yaml3
-rw-r--r--pkgs/development/haskell-modules/hackage-packages.nix6
3 files changed, 6 insertions, 6 deletions
diff --git a/pkgs/development/haskell-modules/configuration-hackage2nix/main.yaml b/pkgs/development/haskell-modules/configuration-hackage2nix/main.yaml
index 9b490fe3af51..d61ab5200ceb 100644
--- a/pkgs/development/haskell-modules/configuration-hackage2nix/main.yaml
+++ b/pkgs/development/haskell-modules/configuration-hackage2nix/main.yaml
@@ -76,8 +76,6 @@ default-package-overrides:
   - http-client-restricted < 0.0.5
   # Downgrade hasql-dynamic-statements until hasql 1.6 is in Stackage
   - hasql-dynamic-statements < 0.3.1.2
-  # Its dependency brick >= 1.0 is not yet in stackage
-  - brick-skylighting < 1.0
   - rope-utf16-splay < 0.4.0.0
   # hnix < 0.17 (unreleased) needs hnix-store-* 0.5.*
   - hnix-store-core == 0.5.0.0            # 2022-06-17: Until hnix 0.17
@@ -103,6 +101,7 @@ extra-packages:
   - basement < 0.0.15                   # 2022-08-30: last version to support GHC < 8.10
   - bower-json == 1.0.0.1               # 2022-05-21: Needed for spago 0.20.9
   - brick == 0.70.*                     # 2022-08-13: needed by matterhorn-50200.17.0
+  - brick-skylighting < 1.0             # 2022-08-13: needed by matterhorn-50200.17.0 to match brick
   - brick == 1.3                        # 2022-11-03: needed by swarm 0.2.0.0
   - brittany == 0.13.1.2                # 2022-09-20: needed for hls on ghc 8.8
   - cabal-install-parsers < 0.5         # 2022-08-31: required by haskell-ci 0.14.3
diff --git a/pkgs/development/haskell-modules/hackage-packages.nix b/pkgs/development/haskell-modules/hackage-packages.nix
index ca28ad8eff34..0093043ca56f 100644
--- a/pkgs/development/haskell-modules/hackage-packages.nix
+++ b/pkgs/development/haskell-modules/hackage-packages.nix
@@ -48691,7 +48691,7 @@ self: {
        mainProgram = "mywork-example";
      }) {};
 
-  "brick-skylighting" = callPackage
+  "brick-skylighting_0_3" = callPackage
     ({ mkDerivation, base, brick, containers, skylighting-core, text
      , vty
      }:
@@ -48706,9 +48706,10 @@ self: {
        ];
        description = "Show syntax-highlighted text in your Brick UI";
        license = lib.licenses.bsd3;
+       hydraPlatforms = lib.platforms.none;
      }) {};
 
-  "brick-skylighting_1_0" = callPackage
+  "brick-skylighting" = callPackage
     ({ mkDerivation, base, brick, containers, skylighting-core, text
      , vty
      }:
@@ -48723,7 +48724,6 @@ self: {
        ];
        description = "Show syntax-highlighted text in your Brick UI";
        license = lib.licenses.bsd3;
-       hydraPlatforms = lib.platforms.none;
      }) {};
 
   "bricks" = callPackage
diff --git a/pkgs/development/haskell-modules/configuration-common.nix b/pkgs/development/haskell-modules/configuration-common.nix
index 3bb605e00668..548110cafc11 100644
--- a/pkgs/development/haskell-modules/configuration-common.nix
+++ b/pkgs/development/haskell-modules/configuration-common.nix
@@ -200,9 +200,10 @@ self: super: {
   # base bound
   digit = doJailbreak super.digit;
 
   # matterhorn-50200.17.0 won't work with brick >= 0.71
   matterhorn = doJailbreak (super.matterhorn.overrideScope (self: super: {
     brick = self.brick_0_70_1;
+    brick-skylighting = self.brick-skylighting_0_3;
   }));
 
   # 2020-06-05: HACK: does not pass own build suite - `dontCheck`
@@ -200,9 +200,10 @@ self: super: {
   digit = doJailbreak super.digit;
 
-  # matterhorn-50200.17.0 won't work with brick >= 0.71
+  # matterhorn-50200.17.0 won't work with brick >= 0.71, brick-skylighting >= 1.0
   matterhorn = doJailbreak (super.matterhorn.overrideScope (self: super: {
     brick = self.brick_0_70_1;